﻿##############################################################################
##
## Power Shell Module for Proxy Gateway Server Object Model Constants
##
##############################################################################

#
# Gateway Well known Group IDs (of top )
#
Set-Variable groupIDManagedHosts -Option Constant -Value "{5C11BD82-CFAA-11DE-847B-005056C00008}"
Set-Variable groupIDSystem -Option Constant -Value "{5C11BD84-CFAA-11DE-847B-005056C00008}"
Set-Variable groupIDUnmanagedHosts -Option Constant -Value "{5C11BD8A-CFAA-11DE-847B-005056C00008}"
Set-Variable groupIDMyHosts -Option Constant -Value "{5C11BD8F-CFAA-11DE-847B-005056C00008}"

#
# Gateway Group Types
#
Set-Variable groupTypeNormal -Option Constant -Value 0x00000000

# Flags to indicate different types of groups or different behaviors
# We reserve the bits ff000000 for system-defined behaviors, like ActiveDirectory, which users cannot change:
Set-Variable groupTypeSystemFlags -Option Constant -Value 0xff000000     # a mask which covers all system-defined bits
Set-Variable groupTypeSystem -Option Constant -Value 0x40000000          # indicates a system-defined group, like ManagedHosts
Set-Variable groupTypeActiveDirectory -Option Constant -Value 0x20000000 # indicates a group created automatically via AD synch
Set-Variable groupTypeVirtual -Option Constant -Value 0x80000000         # indicates a virtual group like "My Hosts" which has no database row

# We reserve the bits 00ff0000 for user-changeable behaviors, like stickiness:
Set-Variable groupTypeUserEditable -Option Constant -Value 0x00ff0000    # a mask which covers all user-changeable bits
Set-Variable groupTypeSticky -Option Constant -Value 0x00010000          # indicates a user-defined group that retains its members regardless of host grouping rules

# The lower 16 bits 0000ffff are used enumerate specific groups or subgroups
# NOTE: up until v8.50 individual groups have been given distinct bits, but this is unnecessary,
# and in future specific groups can be given sequential values, e.g. groupTypeSystem|0x0003 would be fine.
Set-Variable groupTypeManagedHosts -Option Constant -Value ($script:groupTypeSystem -bor 0x1)
Set-Variable groupTypeSystemInfo -Option Constant -Value ($script:groupTypeSystem -bor 0x2)
Set-Variable groupTypeDebugging -Option Constant -Value ($script:groupTypeSystem -bor 0x4)
Set-Variable groupTypeTransientHosts -Option Constant -Value ($script:groupTypeSystem -bor 0x8)
Set-Variable groupTypeTerminalServices -Option Constant -Value ($script:groupTypeSystem -bor 0x10)
Set-Variable groupTypeUnmanagedHosts -Option Constant -Value ($script:groupTypeSystem -bor 0x20)
Set-Variable groupTypeMyHosts -Option Constant -Value ($script:groupTypeSystem -bor 0x40)

# ?
# Win32_ACE Class constants
#
Set-Variable _ACE_Flag_OBJECT_INHERIT_ACE -Option Constant -Value 0x1
Set-Variable _ACE_Flag_CONTAINER_INHERIT_ACE -Option Constant -Value 0x2

Set-Variable _ACE_Type_Access_Allowed -Option Constant -Value 0x0
Set-Variable _ACE_Type_Access_Denied -Option Constant -Value 0x1
Set-Variable _ACE_Type_Audit -Option Constant -Value 0x2

#
# Gateway Account Security
#

# UserCategory Enum
Set-Variable usercatUnknown			 -Option Constant -Value -1	# Init value
Set-Variable usercatSystem			 -Option Constant -Value 0	# I.e. the Gateway itself, no rights filtered
Set-Variable usercatAdministrator	 -Option Constant -Value 1	# no rights filtered
Set-Variable usercatMaster			 -Option Constant -Value 2	# rights restricted to Gateway connect, NO settings or operations access, NO edit security rights, usually given access to a Group of Hosts
Set-Variable usercatPersonal         -Option Constant -Value 3	# rights restricted to Gateway connect, NO settings or operations access, NO access to anything else except one Host
Set-Variable usercatLimitedAdmin	 -Option Constant -Value 4	# rights restricted to Gateway connect and View/Modify Active collections, plus view Settings and All Hosts

Set-Variable userCategoryMap -Option Constant -Value @{ 
    $script:usercatUnknown = "usercatUnknown";
    $script:usercatSystem = "usercatSystem";
    $script:usercatAdministrator = "usercatAdministrator";
    $script:usercatMaster = "usercatMaster";
    $script:usercatPersonal = "usercatPersonal";
    $script:usercatLimitedAdmin = "usercatLimitedAdmin";
}

#
# Access Rights Constants
#

#
# Standart rights
#
Set-Variable DELETE -Option Constant -Value 0x00010000
Set-Variable READ_CONTROL -Option Constant -Value 0x00020000
Set-Variable WRITE_DAC -Option Constant -Value 0x00040000
Set-Variable WRITE_OWNER -Option Constant -Value 0x00080000

#
# Gateway security rights
#
# Specific rights:
Set-Variable gatewayConnect -Option Constant -Value 0x0001
Set-Variable gatewayReadActiveClients -Option Constant -Value 0x0002
Set-Variable gatewayModifyActiveClients -Option Constant -Value 0x0004
Set-Variable gatewayReadActiveRecordings -Option Constant -Value 0x0008
Set-Variable gatewayModifyActiveRecordings -Option Constant -Value 0x0010
Set-Variable gatewayReadActiveMasters -Option Constant -Value 0x0020
Set-Variable gatewayModifyActiveMasters -Option Constant -Value 0x0040
Set-Variable gatewaySendIPCData -Option Constant -Value 0x0080
Set-Variable gatewayReadActiveHosts -Option Constant -Value 0x0100
Set-Variable gatewayModifyActiveHosts -Option Constant -Value 0x0200
Set-Variable gatewayManageHosts -Option Constant -Value 0x0400
Set-Variable gatewayCreateGroups -Option Constant -Value 0x0800
Set-Variable gatewayReadAuditLogs -Option Constant -Value 0x1000
Set-Variable gatewayReadActiveConcurrentUsers -Option Constant -Value 0x2000

# Internal groupings:
# note: for v5.0 we exclude recording and sendIPC  Also, can't DELETE the Gateway
Set-Variable v50_gatewayAllRights -Option Constant -Value (0x0f67 -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER)
# note: for v5.10 we include recording and sendIPC
Set-Variable v70_gatewayAllRights -Option Constant -Value (0x0fff -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER)
# note: for v8.0 we include gatewayReadAuditLogs and gatewayReadActiveConcurrentUsers
Set-Variable v802_gatewayAllRights -Option Constant -Value (0x3fff -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER)
# NOTE: in v8.50 we're dropping WRITE_OWNER and gatewayCreateGroups
Set-Variable gatewayAllRights -Option Constant -Value (0x37ff -bor $script:READ_CONTROL -bor $script:WRITE_DAC)

# General rights:
Set-Variable gatewayFullControlGeneral -Option Constant -Value $script:gatewayAllRights
Set-Variable gatewayViewInformationGeneral -Option Constant -Value ($script:gatewayConnect -bor $script:gatewayReadActiveClients -bor $script:gatewayReadAuditLogs -bor $script:gatewayReadActiveRecordings -bor $script:gatewayReadActiveMasters -bor $script:gatewayReadActiveConcurrentUsers -bor $script:gatewayReadActiveHosts)
Set-Variable gatewayModifyInformationGeneral -Option Constant -Value ($script:gatewayConnect -bor $script:gatewayReadActiveClients -bor $script:gatewayModifyActiveClients -bor $script:gatewayReadAuditLogs -bor $script:gatewayReadActiveRecordings -bor $script:gatewayModifyActiveRecordings -bor $script:gatewayReadActiveMasters -bor $script:gatewayModifyActiveMasters -bor $script:gatewayReadActiveConcurrentUsers -bor $script:gatewayReadActiveHosts -bor $script:gatewayModifyActiveHosts -bor $script:gatewaySendIPCData)
Set-Variable gatewayConnectFromMasterGeneral -Option Constant -Value $script:gatewayConnect

#
# Group security rights
#
# Specific rights:
Set-Variable groupRead -Option Constant -Value 0x0001
Set-Variable groupModify -Option Constant -Value 0x0002 # right to edit group description
Set-Variable groupCreate -Option Constant -Value 0x0004	# right to create subgroups

# Internal groupings:
Set-Variable v802_groupAllRights -Option Constant -Value (0x0003 -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER -bor $script:DELETE)
Set-Variable groupAllRights -Option Constant -Value (0x0007 -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:DELETE)

# General rights:
Set-Variable groupFullControlGeneral -Option Constant -Value $script:groupAllRights
Set-Variable groupModifyGeneral -Option Constant -Value ($script:groupRead -bor $script:groupModify)
Set-Variable groupDeleteGeneral -Option Constant -Value ($script:DELETE -bor $script:groupRead)
Set-Variable groupVisibleGeneral -Option Constant -Value $script:groupRead

#
# Host security rights
#
# Specific rights:
Set-Variable hostRead -Option Constant -Value 0x0001
Set-Variable hostConnect -Option Constant -Value 0x0002
Set-Variable hostRemoteView -Option Constant -Value 0x0004
Set-Variable hostRemoteControl -Option Constant -Value 0x0008
Set-Variable hostFileTransferRead -Option Constant -Value 0x0010
Set-Variable hostFileTransferWrite -Option Constant -Value 0x0020
Set-Variable hostRemotePrinting -Option Constant -Value 0x0040
Set-Variable hostClipboardRead -Option Constant -Value 0x0080
Set-Variable hostClipboardWrite -Option Constant -Value 0x0100
Set-Variable hostStartRecording -Option Constant -Value 0x0200
Set-Variable hostTakeInputControl -Option Constant -Value 0x0400
Set-Variable hostAdmin -Option Constant -Value 0x0800
Set-Variable hostChat -Option Constant -Value 0x1000
Set-Variable hostRemoteManagement -Option Constant -Value 0x2000
Set-Variable hostBypassConnectionPermission -Option Constant -Value 0x8000 # note: special right given only to SuperAdmins who aren't subject to 

# Internal groupings:
Set-Variable v50_hostAllRights -Option Constant -Value (0x0dff -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER -bor $script:DELETE)
Set-Variable v510_hostAllRights -Option Constant -Value (0x0fff -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER -bor $script:DELETE)
Set-Variable v60_hostAllRights -Option Constant -Value (0x1fff -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER -bor $script:DELETE)
Set-Variable v802_hostAllRights -Option Constant -Value ($script:DELETE -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER -bor $script:hostRead -bor $script:hostConnect -bor $script:hostRemoteView -bor $script:hostRemoteControl -bor $script:hostFileTransferRead -bor $script:hostFileTransferWrite -bor $script:hostRemotePrinting -bor $script:hostClipboardRead -bor $script:hostClipboardWrite -bor $script:hostStartRecording -bor $script:hostTakeInputControl -bor $script:hostAdmin -bor $script:hostChat -bor $script:hostRemoteManagement)
Set-Variable hostAllRights -Option Constant -Value ($script:DELETE -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:hostRead -bor $script:hostConnect -bor $script:hostRemoteView -bor $script:hostRemoteControl -bor $script:hostFileTransferRead -bor $script:hostFileTransferWrite -bor $script:hostRemotePrinting -bor $script:hostClipboardRead -bor $script:hostClipboardWrite -bor $script:hostStartRecording -bor $script:hostTakeInputControl -bor $script:hostAdmin -bor $script:hostChat -bor $script:hostRemoteManagement)

# General rights:
Set-Variable hostFullControlGeneral -Option Constant -Value $script:hostAllRights
Set-Variable hostFullUserGeneral -Option Constant -Value ($script:hostRead -bor $script:hostConnect -bor $script:hostRemoteView -bor $script:hostRemoteControl -bor $script:hostFileTransferRead -bor $script:hostFileTransferWrite -bor $script:hostRemotePrinting -bor $script:hostClipboardRead -bor $script:hostClipboardWrite -bor $script:hostStartRecording -bor $script:hostTakeInputControl -bor $script:hostAdmin -bor $script:hostChat -bor $script:hostRemoteManagement)
Set-Variable hostRemoteControlGeneral -Option Constant -Value ($script:hostRead -bor $script:hostConnect -bor $script:hostRemoteView -bor $script:hostRemoteControl -bor $script:hostStartRecording -bor $script:hostTakeInputControl)
Set-Variable hostViewOnlyGeneral -Option Constant -Value ($script:hostRead -bor $script:hostConnect -bor $script:hostRemoteView -bor $script:hostStartRecording)
Set-Variable hostFileTransferGeneral -Option Constant -Value ($script:hostRead -bor $script:hostConnect -bor $script:hostRemoteView -bor $script:hostFileTransferRead -bor $script:hostFileTransferWrite)
Set-Variable hostRemoteAdminGeneral -Option Constant -Value ($script:hostRead -bor $script:hostAdmin)
Set-Variable hostRemoteManagementGeneral -Option Constant -Value ($script:hostRead -bor $script:hostAdmin -bor $script:hostConnect -bor $script:hostRemoteView -bor $script:hostRemoteManagement)

#
# Operation security rights
#
# Specific rights:
Set-Variable operationRecordToFile -Option Constant -Value 0x0001
Set-Variable operationConnectToFile -Option Constant -Value 0x0002
Set-Variable operationImportSession -Option Constant -Value 0x0004
# note: no need for operationRemoveSession -- that's covered by DELETE on the session record
Set-Variable operationDiagnosticAccess -Option Constant -Value 0x0008
Set-Variable operationIntegrityCheck -Option Constant -Value 0x0010

# Internal groupings:
Set-Variable v802_operationAllRights -Option Constant -Value (0x000F -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER) # note: can't DELETE the Operations
Set-Variable operationAllRights -Option Constant -Value (0x001F -bor $script:READ_CONTROL -bor $script:WRITE_DAC)

# General rights:
Set-Variable operationFullControlGeneral -Option Constant -Value ($script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:operationImportSession -bor $script:operationDiagnosticAccess -bor $script:operationIntegrityCheck)

#
# Session security rights
#
# Specific rights:
Set-Variable sessionRead -Option Constant -Value 0x0001
Set-Variable sessionPlay -Option Constant -Value 0x0002
Set-Variable sessionModify -Option Constant -Value 0x0004 

# Internal groupings:
Set-Variable v802_sessionAllRights -Option Constant -Value (0x0003 -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER -bor $script:DELETE)
Set-Variable sessionAllRights -Option Constant -Value ($script:0x0003 -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:DELETE)

# General rights:
Set-Variable sessionFullControlGeneral -Option Constant -Value ($script:DELETE -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:sessionRead -bor $script:sessionPlay)
Set-Variable sessionFullUserGeneral -Option Constant -Value ($script:sessionRead -bor $script:sessionPlay)
Set-Variable sessionDeleteGeneral -Option Constant -Value ($script:DELETE -bor $script:sessionRead)

#
# Settings security rights
#
# Specific rights:
Set-Variable settingsRead -Option Constant -Value 0x0001
Set-Variable settingsWrite -Option Constant -Value 0x0002
Set-Variable settingsReadLicenses -Option Constant -Value 0x0004
Set-Variable settingsWriteLicenses -Option Constant -Value 0x0008
Set-Variable settingsReadPollSettings -Option Constant -Value 0x0010
Set-Variable settingsWritePollSettings -Option Constant -Value 0x0020
Set-Variable settingsReadProtocols -Option Constant -Value 0x0040
Set-Variable settingsWriteProtocols -Option Constant -Value 0x0080
Set-Variable settingsReadAuditSettings -Option Constant -Value 0x0100
Set-Variable settingsWriteAuditSettings -Option Constant -Value 0x0200
Set-Variable settingsReadEncryption -Option Constant -Value 0x0400
Set-Variable settingsWriteEncryption -Option Constant -Value 0x0800
Set-Variable settingsReadRecordingSettings -Option Constant -Value 0x1000
Set-Variable settingsWriteRecordingSettings -Option Constant -Value 0x2000
Set-Variable settingsReadHostGroupingRules -Option Constant -Value 0x4000
Set-Variable settingsWriteHostGroupingRules -Option Constant -Value 0x8000
Set-Variable settingsReadAccounts -Option Constant -Value 0x00100000
Set-Variable settingsWriteAccounts -Option Constant -Value 0x00200000
Set-Variable settingsReadIdentities -Option Constant -Value 0x00400000
Set-Variable settingsWriteIdentities -Option Constant -Value 0x00800000
Set-Variable settingsReadWebConsoleUI -Option Constant -Value 0x01000000
Set-Variable settingsWriteWebConsoleUI -Option Constant -Value 0x02000000
Set-Variable settingsReadWebConsoleApps -Option Constant -Value 0x04000000
Set-Variable settingsWriteWebConsoleApps -Option Constant -Value 0x08000000
Set-Variable settingsReadAutoRecordingSettings -Option Constant -Value 0x10000000
Set-Variable settingsWriteAutoRecordingSettings -Option Constant -Value 0x20000000
Set-Variable settingsAccessPIMSettings -Option Constant -Value 0x40000000

# Internal groupings:
# note: can't DELETE the Settings
Set-Variable v50_settingsAllRights -Option Constant -Value (0x0fff -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER)
Set-Variable v80_settingsAllRights -Option Constant -Value (0x3fff -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER)
Set-Variable v802_settingsAllRights -Option Constant -Value (0xffff -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER)
Set-Variable settingsAllRights -Option Constant -Value (0x7ff0ffff -bor $script:READ_CONTROL -bor $script:WRITE_DAC)

# General rights:
Set-Variable settingsFullControlGeneral -Option Constant -Value $script:settingsAllRights
Set-Variable settingsViewSettingsGeneral -Option Constant -Value ($script:settingsRead -bor $script:settingsReadLicenses -bor $script:settingsReadPollSettings -bor $script:settingsReadProtocols -bor $script:settingsReadAuditSettings -bor $script:settingsReadEncryption -bor $script:settingsReadRecordingSettings -bor $script:settingsReadHostGroupingRules -bor $script:settingsReadAccounts -bor $script:settingsReadIdentities -bor $script:settingsReadWebConsoleUI -bor $script:settingsReadWebConsoleApps -bor $script:settingsReadAutoRecordingSettings)
Set-Variable settingsModifySettingsGeneral -Option Constant -Value ($script:settingsRead -bor $script:settingsWrite -bor $script:settingsReadLicenses -bor $script:settingsWriteLicenses -bor $script:settingsReadPollSettings -bor $script:settingsWritePollSettings -bor $script:settingsReadProtocols -bor $script:settingsWriteProtocols -bor $script:settingsReadAuditSettings -bor $script:settingsWriteAuditSettings -bor $script:settingsReadEncryption -bor $script:settingsWriteEncryption -bor $script:settingsReadRecordingSettings -bor $script:settingsWriteRecordingSettings -bor $script:settingsReadHostGroupingRules -bor $script:settingsWriteHostGroupingRules -bor $script:settingsReadAccounts -bor $script:settingsWriteAccounts -bor $script:settingsReadIdentities -bor $script:settingsWriteIdentities -bor $script:settingsReadWebConsoleUI -bor $script:settingsWriteWebConsoleUI -bor $script:settingsReadWebConsoleApps -bor $script:settingsWriteWebConsoleApps -bor $script:settingsReadAutoRecordingSettings -bor $script:settingsWriteAutoRecordingSettings -bor $script:settingsAccessPIMSettings)

#
# AutoRecording security rights
#
# Specific rights:
Set-Variable autoRecordingRecordOnConnect -Option Constant -Value 0x0001

# Internal groupings:
Set-Variable autoRecordingAllRights -Option Constant -Value (0x0001 -bor $script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER)

# General rights:
Set-Variable autoRecordingFullControlGeneral -Option Constant -Value ($script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER -bor $script:autoRecordingRecordOnConnect)
Set-Variable autoRecordingEditSecurityGeneral -Option Constant -Value ($script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER)

#
# Security rights Name Maps = @{ accessRightBinaryFlag = "accessRightName" }
#
Set-Variable settingsSecRightsMap -Option Constant -Value @{ 
    $script:DELETE = "DELETE";
    $script:READ_CONTROL = "READ_CONTROL";
    $script:WRITE_DAC = "WRITE_DAC";
    $script:WRITE_OWNER = "WRITE_OWNER";
    $script:settingsRead = "settingsRead";
    $script:settingsWrite = "settingsWrite";
    $script:settingsReadLicenses = "settingsReadLicenses";
    $script:settingsWriteLicenses = "settingsWriteLicenses";
    $script:settingsReadPollSettings = "settingsReadPollSettings";
    $script:settingsWritePollSettings = "settingsWritePollSettings";
    $script:settingsReadProtocols = "settingsReadProtocols";
    $script:settingsWriteProtocols = "settingsWriteProtocols";
    $script:settingsReadAuditSettings = "settingsReadAuditSettings";
    $script:settingsWriteAuditSettings = "settingsWriteAuditSettings";
    $script:settingsReadEncryption = "settingsReadEncryption";
    $script:settingsWriteEncryption = "settingsWriteEncryption";
    $script:settingsReadRecordingSettings = "settingsReadRecordingSettings";
    $script:settingsWriteRecordingSettings = "settingsWriteRecordingSettings";
    $script:settingsReadHostGroupingRules = "settingsReadHostGroupingRules";
    $script:settingsWriteHostGroupingRules = "settingsWriteHostGroupingRules";
    $script:settingsReadAccounts = "settingsReadAccounts";
    $script:settingsWriteAccounts = "settingsWriteAccounts";
    $script:settingsReadIdentities = "settingsReadIdentities";
    $script:settingsWriteIdentities = "settingsWriteIdentities";
    $script:settingsReadWebConsoleUI = "settingsReadWebConsoleUI";
    $script:settingsWriteWebConsoleUI = "settingsWriteWebConsoleUI";
    $script:settingsReadWebConsoleApps = "settingsReadWebConsoleApps";
    $script:settingsWriteWebConsoleApps = "settingsWriteWebConsoleApps";
    $script:settingsReadAutoRecordingSettings = "settingsReadAutoRecordingSettings";
    $script:settingsWriteAutoRecordingSettings = "settingsWriteAutoRecordingSettings";
    $script:settingsAccessPIMSettings = "settingsAccessPIMSettings";
    $script:v50_settingsAllRights = "v50_settingsAllRights";
    $script:v80_settingsAllRights = "v80_settingsAllRights";
    $script:v802_settingsAllRights = "v802_settingsAllRights";
    $script:settingsAllRights = "settingsAllRights";
}

Set-Variable gatewaySecRightsMap -Option Constant -Value @{ 
    $script:DELETE = "DELETE";
    $script:READ_CONTROL = "READ_CONTROL";
    $script:WRITE_DAC = "WRITE_DAC";
    $script:WRITE_OWNER = "WRITE_OWNER";
    $script:gatewayConnect = "gatewayConnect";
    $script:gatewayReadActiveClients = "gatewayReadActiveClients";
    $script:gatewayModifyActiveClients = "gatewayModifyActiveClients";
    $script:gatewayReadActiveRecordings = "gatewayReadActiveRecordings";
    $script:gatewayModifyActiveRecordings = "gatewayModifyActiveRecordings";
    $script:gatewayReadActiveMasters = "gatewayReadActiveMasters";
    $script:gatewayModifyActiveMasters = "gatewayModifyActiveMasters";
    $script:gatewaySendIPCData = "gatewaySendIPCData";
    $script:gatewayReadActiveHosts = "gatewayReadActiveHosts";
    $script:gatewayModifyActiveHosts = "gatewayModifyActiveHosts";
    $script:gatewayManageHosts = "gatewayManageHosts";
    $script:gatewayCreateGroups = "gatewayCreateGroups";
    $script:gatewayReadAuditLogs = "gatewayReadAuditLogs";
    $script:gatewayReadActiveConcurrentUsers = "gatewayReadActiveConcurrentUsers";
    $script:v50_gatewayAllRights = "v50_gatewayAllRights";
    $script:v70_gatewayAllRights = "v70_gatewayAllRights";
    $script:v802_gatewayAllRights = "v802_gatewayAllRights";
    $script:gatewayAllRights = "gatewayAllRights";
}

Set-Variable groupSecRightsMap -Option Constant -Value @{ 
    $script:DELETE = "DELETE";
    $script:READ_CONTROL = "READ_CONTROL";
    $script:WRITE_DAC = "WRITE_DAC";
    $script:WRITE_OWNER = "WRITE_OWNER";
    $script:groupRead = "groupRead";
    $script:groupModify = "groupModify";
    $script:groupCreate = "groupCreate";
    $script:v802_groupAllRights = "v802_groupAllRights";
    $script:groupAllRights = "groupAllRights";
}

Set-Variable hostSecRightsMap -Option Constant -Value @{ 
    $script:DELETE = "DELETE";
    $script:READ_CONTROL = "READ_CONTROL";
    $script:WRITE_DAC = "WRITE_DAC";
    $script:WRITE_OWNER = "WRITE_OWNER";
    $script:hostRead  = "hostRead ";
    $script:hostConnect  = "hostConnect ";
    $script:hostRemoteView  = "hostRemoteView ";
    $script:hostRemoteControl  = "hostRemoteControl ";
    $script:hostFileTransferRead  = "hostFileTransferRead ";
    $script:hostFileTransferWrite  = "hostFileTransferWrite ";
    $script:hostRemotePrinting  = "hostRemotePrinting ";
    $script:hostClipboardRead  = "hostClipboardRead ";
    $script:hostClipboardWrite  = "hostClipboardWrite ";
    $script:hostStartRecording  = "hostStartRecording ";
    $script:hostTakeInputControl  = "hostTakeInputControl ";
    $script:hostAdmin  = "hostAdmin ";
    $script:hostChat  = "hostChat ";
    $script:hostRemoteManagement  = "hostRemoteManagement ";
    $script:hostBypassConnectionPermission  = "hostBypassConnectionPermission ";
    $script:v50_hostAllRights  = "v50_hostAllRights ";
    $script:v510_hostAllRights  = "v510_hostAllRights ";
    $script:v60_hostAllRights  = "v60_hostAllRights ";
    $script:v802_hostAllRights  = "v802_hostAllRights ";
    $script:hostAllRights  = "hostAllRights ";
}

Set-Variable operationSecRightsMap -Option Constant -Value @{ 
    $script:DELETE = "DELETE";
    $script:READ_CONTROL = "READ_CONTROL";
    $script:WRITE_DAC = "WRITE_DAC";
    $script:WRITE_OWNER = "WRITE_OWNER";
    $script:operationRecordToFile  = "operationRecordToFile ";
    $script:operationConnectToFile  = "operationConnectToFile ";
    $script:operationImportSession  = "operationImportSession ";
    $script:operationDiagnosticAccess  = "operationDiagnosticAccess ";
    $script:operationIntegrityCheck  = "operationIntegrityCheck ";
    $script:v802_operationAllRights  = "v802_operationAllRights ";
    $script:operationAllRights  = "operationAllRights ";
}

Set-Variable sessionSecRightsMap -Option Constant -Value @{ 
    $script:DELETE = "DELETE";
    $script:READ_CONTROL = "READ_CONTROL";
    $script:WRITE_DAC = "WRITE_DAC";
    $script:WRITE_OWNER = "WRITE_OWNER";
    $script:sessionRead = "sessionRead";
    $script:sessionPlay = "sessionPlay";
    $script:sessionModify = "sessionModify";
    $script:v802_sessionAllRights = "v802_sessionAllRights";
    $script:sessionAllRights = "sessionAllRights";
}

Set-Variable autoRecordingSecRightsMap -Option Constant -Value @{ 
    $script:DELETE = "DELETE";
    $script:READ_CONTROL = "READ_CONTROL";
    $script:WRITE_DAC = "WRITE_DAC";
    $script:WRITE_OWNER = "WRITE_OWNER";
    $script:autoRecordingRecordOnConnect = "autoRecordingRecordOnConnect";
    $script:autoRecordingAllRights = "autoRecordingAllRights";
}

#
# Host security rights enums
#

#
# HostAdmin security rights
#
# Specific rights:
Set-Variable hostadminConnectLocally -Option Constant -Value 0x01
Set-Variable hostadminReadHostStatus -Option Constant -Value 0x02
Set-Variable hostadminTerminateConnection -Option Constant -Value 0x04
Set-Variable hostadminConnectRemotely -Option Constant -Value 0x08
Set-Variable hostadminPauseResumeScreenCap -Option Constant -Value 0x0010
Set-Variable hostadminRemoteManagement -Option Constant -Value 0x0020
Set-Variable hostadminSetControlConnection -Option Constant -Value 0x0100	# note: special right given only to Gateways

# Internal groupings:
Set-Variable v60_hostadminAllRights	 -Option Constant -Value 0x000F # was OR of all bits above
Set-Variable v602_hostadminAllRights -Option Constant -Value 0x001F # was OR of all bits above
Set-Variable hostadminAllRights		 -Option Constant -Value 0x003F # must be OR of all bits above (except SetControlConnection)

# General rights:
Set-Variable hostadminFullControlGeneral		 -Option Constant -Value ($script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER -bor $script:hostadminAllRights)
Set-Variable hostadminFullUserGeneral		 -Option Constant -Value $script:hostadminAllRights
Set-Variable hostadminFullLocalUserGeneral	 -Option Constant -Value ($script:hostadminConnectLocally -bor $script:hostadminReadHostStatus -bor $script:hostadminTerminateConnection -bor $script:hostadminPauseResumeScreenCap)
Set-Variable hostadminAccessTrayGeneral		 -Option Constant -Value ($script:hostadminConnectLocally -bor $script:hostadminReadHostStatus)
Set-Variable hostadminPauseResumeGeneral		 -Option Constant -Value ($script:hostadminConnectLocally -bor $script:hostadminReadHostStatus -bor $script:hostadminPauseResumeScreenCap)

Set-Variable hostAdminSecRightsMap -Option Constant -Value @{ 
    $script:DELETE = "DELETE";
    $script:READ_CONTROL = "READ_CONTROL";
    $script:WRITE_DAC = "WRITE_DAC";
    $script:WRITE_OWNER = "WRITE_OWNER";
    $script:hostadminConnectLocally  = "hostadminConnectLocally ";
    $script:hostadminReadHostStatus  = "hostadminReadHostStatus ";
    $script:hostadminTerminateConnection  = "hostadminTerminateConnection ";
    $script:hostadminConnectRemotely  = "hostadminConnectRemotely ";
    $script:hostadminPauseResumeScreenCap  = "hostadminPauseResumeScreenCap ";
    $script:hostadminRemoteManagement  = "hostadminRemoteManagement ";
    $script:hostadminSetControlConnection  = "hostadminSetControlConnection ";
    $script:v60_hostadminAllRights	  = "v60_hostadminAllRights	 ";
    $script:v602_hostadminAllRights  = "v602_hostadminAllRights ";
    $script:hostadminAllRights		  = "hostadminAllRights		 ";
}

#
#  HostService security rights
#
# Specific rights:
Set-Variable hostserviceConnect -Option Constant -Value 0x01
Set-Variable hostserviceRemoteView -Option Constant -Value 0x02
Set-Variable hostserviceRemoteControl -Option Constant -Value 0x04
Set-Variable hostserviceFileTransferRead -Option Constant -Value 0x08
Set-Variable hostserviceFileTransferWrite -Option Constant -Value 0x10
Set-Variable hostserviceRemotePrinting -Option Constant -Value 0x20
Set-Variable hostserviceClipboardTransferRead -Option Constant -Value 0x40
Set-Variable hostserviceClipboardTransferWrite -Option Constant -Value 0x80
Set-Variable hostserviceChat -Option Constant -Value 0x100
Set-Variable hostserviceBypassConnectionPermission -Option Constant -Value 0x8000 # special right given only to SuperAdmins who aren't subject to connection permission

# Internal groupings:
Set-Variable v50_hostserviceAllRights -Option Constant -Value 0x0FF
Set-Variable hostserviceAllRights -Option Constant -Value 0x1FF # must be OR of all bits above

# General rights:
Set-Variable hostserviceFullControlGeneral -Option Constant -Value ($script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER -bor $script:hostserviceAllRights)
Set-Variable hostserviceFullUserGeneral -Option Constant -Value ($script:hostserviceConnect -bor $script:hostserviceRemoteView -bor $script:hostserviceRemoteControl -bor $script:hostserviceFileTransferRead -bor $script:hostserviceFileTransferWrite -bor $script:hostserviceRemotePrinting -bor $script:hostserviceClipboardTransferRead -bor $script:hostserviceClipboardTransferWrite -bor $script:hostserviceChat)
Set-Variable hostserviceRemoteControlGeneral -Option Constant -Value ($script:hostserviceConnect -bor $script:hostserviceRemoteView -bor $script:hostserviceRemoteControl)
Set-Variable hostserviceViewOnlyGeneral -Option Constant -Value ($script:hostserviceConnect -bor $script:hostserviceRemoteView)
Set-Variable hostserviceFileTransferGeneral -Option Constant -Value ($script:hostserviceConnect -bor $script:hostserviceFileTransferRead -bor $script:hostserviceFileTransferWrite)

Set-Variable hostServiceSecRightsMap -Option Constant -Value @{ 
    $script:DELETE = "DELETE";
    $script:READ_CONTROL = "READ_CONTROL";
    $script:WRITE_DAC = "WRITE_DAC";
    $script:WRITE_OWNER = "WRITE_OWNER";
    $script:hostserviceConnect  = "hostserviceConnect ";
    $script:hostserviceRemoteView  = "hostserviceRemoteView ";
    $script:hostserviceRemoteControl  = "hostserviceRemoteControl ";
    $script:hostserviceFileTransferRead  = "hostserviceFileTransferRead ";
    $script:hostserviceFileTransferWrite  = "hostserviceFileTransferWrite ";
    $script:hostserviceRemotePrinting  = "hostserviceRemotePrinting ";
    $script:hostserviceClipboardTransferRead  = "hostserviceClipboardTransferRead ";
    $script:hostserviceClipboardTransferWrite  = "hostserviceClipboardTransferWrite ";
    $script:hostserviceChat  = "hostserviceChat ";
    $script:hostserviceBypassConnectionPermission  = "hostserviceBypassConnectionPermission ";
    $script:v50_hostserviceAllRights  = "v50_hostserviceAllRights ";
    $script:hostserviceAllRights  = "hostserviceAllRights ";
}

#
#  HostSettings security rights
#
# Specific rights:
Set-Variable hostsettingsRead -Option Constant -Value 0x01
Set-Variable hostsettingsWrite -Option Constant -Value 0x02
Set-Variable hostsettingsWriteAccess -Option Constant -Value 0x04
Set-Variable hostsettingsReadLicenses -Option Constant -Value 0x08
Set-Variable hostsettingsWriteLicenses -Option Constant -Value 0x10
Set-Variable hostsettingsReadGatewayConfigs -Option Constant -Value 0x20
Set-Variable hostsettingsWriteGatewayConfigs -Option Constant -Value 0x40
Set-Variable hostsettingsReadDiagnostics -Option Constant -Value 0x80
Set-Variable hostsettingsWriteEx -Option Constant -Value 0x100
Set-Variable hostsettingsReadWriteExtensionTags -Option Constant -Value 0x200

# Internal groupings:
Set-Variable v40_hostsettingsAllRights		 -Option Constant -Value 0x001F
Set-Variable v702_hostsettingsAllRights		 -Option Constant -Value 0x00FF	# was OR of all bits above (except hostsettingsWriteEx)
Set-Variable hostsettingsAllRights			 -Option Constant -Value 0x02FF	# must be OR of all bits above (except hostsettingsWriteEx)

# General rights:
Set-Variable hostsettingsFullControlGeneral	 -Option Constant -Value ($script:READ_CONTROL -bor $script:WRITE_DAC -bor $script:WRITE_OWNER -bor $script:hostsettingsAllRights)
Set-Variable hostsettingsFullUserGeneral		 -Option Constant -Value ($script:hostsettingsRead -bor $script:hostsettingsWrite -bor $script:hostsettingsWriteAccess -bor $script:hostsettingsReadLicenses -bor $script:hostsettingsWriteLicenses -bor $script:hostsettingsReadGatewayConfigs -bor $script:hostsettingsWriteGatewayConfigs -bor $script:hostsettingsReadDiagnostics -bor $script:hostsettingsReadWriteExtensionTags)
Set-Variable hostsettingsReadGeneral			 -Option Constant -Value ($script:hostsettingsRead -bor $script:hostsettingsReadLicenses -bor $script:hostsettingsReadGatewayConfigs -bor $script:hostsettingsReadDiagnostics)
Set-Variable hostsettingsModifyBasicSettingsGeneral  -Option Constant -Value ($script:hostsettingsRead -bor $script:hostsettingsWrite -bor $script:hostsettingsReadDiagnostics)

Set-Variable hostSettingsSecRightsMap -Option Constant -Value @{ 
    $script:hostsettingsRead = "hostsettingsRead";
    $script:hostsettingsWrite = "hostsettingsWrite";
    $script:hostsettingsWriteAccess = "hostsettingsWriteAccess";
    $script:hostsettingsReadLicenses = "hostsettingsReadLicenses";
    $script:hostsettingsWriteLicenses = "hostsettingsWriteLicenses";
    $script:hostsettingsReadGatewayConfigs = "hostsettingsReadGatewayConfigs";
    $script:hostsettingsWriteGatewayConfigs = "hostsettingsWriteGatewayConfigs";
    $script:hostsettingsReadDiagnostics = "hostsettingsReadDiagnostics";
    $script:hostsettingsWriteEx = "hostsettingsWriteEx";
    $script:hostsettingsReadWriteExtensionTags = "hostsettingsReadWriteExtensionTags";
    $script:v40_hostsettingsAllRights		 = "v40_hostsettingsAllRights";
    $script:v702_hostsettingsAllRights		 = "v702_hostsettingsAllRights";
    $script:hostsettingsAllRights			 = "hostsettingsAllRights";
}

#
# Host settings enums
#

# WindowAppearance Enum
Set-Variable windowHide -Option Constant -Value 0
Set-Variable windowIcon -Option Constant -Value 2

Set-Variable windowAppearance -Option Constant -Value @{ 
    0 = "windowHide";
    2 = "windowIcon"}

# hostNotifications Property
Set-Variable notifyOnConnectDisconnect -Option Constant -Value 0x01
Set-Variable notifyOnFileTransferOperations -Option Constant -Value 0x02
Set-Variable notifyShowActiveUsersAtConnect -Option Constant -Value 0x10000

Set-Variable hostNotificationsMap -Option Constant -Value @{ 
    0x01    = "notifyOnConnectDisconnect";
    0x02    = "notifyOnFileTransferOperations";
    0x10000 = "notifyShowActiveUsersAtConnect"}

# SuppressKeys Enum
Set-Variable suppressAlways -Option Constant -Value 0
Set-Variable suppressPermit -Option Constant -Value 1
Set-Variable suppressNever -Option Constant -Value 2

Set-Variable suppressKeysMap -Option Constant -Value @{ 
    0 = "suppressAlways";
    1 = "suppressPermit";
    2 = "suppressNever"}

# HostAccess Enum
Set-Variable accessPermit -Option Constant -Value 0
Set-Variable accessLocked -Option Constant -Value 1
Set-Variable accessTime -Option Constant -Value 2

Set-Variable hostAccessMap -Option Constant -Value @{ 
    0 = "accessPermit";
    1 = "accessLocked";
    2 = "accessTime"}

# HostPermission Enum
Set-Variable permitNone -Option Constant -Value 0
Set-Variable permitGrant -Option Constant -Value 1
Set-Variable permitRequest -Option Constant -Value 2

Set-Variable hostPermissionMap -Option Constant -Value @{ 
    0 = "permitNone";
    1 = "permitGrant";
    2 = "permitRequest"}

# ManageVisualEffectsMode Enum
Set-Variable manageAlways -Option Constant -Value 0
Set-Variable managePermit -Option Constant -Value 1
Set-Variable manageNever -Option Constant -Value 2

Set-Variable manageVisualEffectsModeMap -Option Constant -Value @{ 
    0 = "manageAlways";
    1 = "managePermit";
    2 = "manageNever"}

# VisualEffectsFlags Enum
Set-Variable veNone -Option Constant -Value 0x00
Set-Variable veActiveDesktop -Option Constant -Value 0x01
Set-Variable veWallPaper -Option Constant -Value 0x02
Set-Variable veMouseEffects -Option Constant -Value 0x04
Set-Variable veFontSmoothing -Option Constant -Value 0x08
Set-Variable veWindowEffects -Option Constant -Value 0x10
Set-Variable veFullDrag -Option Constant -Value 0x20
Set-Variable veScreenSaver -Option Constant -Value 0x40
Set-Variable v50_veAllEffects -Option Constant -Value 0x7f
Set-Variable veAeroGlass -Option Constant -Value 0x80
Set-Variable veAllEffects -Option Constant -Value 0xff

Set-Variable visualEffectsFlagsMap -Option Constant -Value @{ 
    0x00 = "veNone";
    0x01 = "veActiveDesktop";
    0x02 = "veWallPaper";
    0x04 = "veMouseEffects";
    0x08 = "veFontSmoothing";
    0x10 = "veWindowEffects";
    0x20 = "veFullDrag";
    0x40 = "veScreenSaver";
    0x7F = "v50_veAllEffects"
    0x80 = "veAeroGlass";
    0xff = "veAllEffects"}


#
# Module exports
#
Export-ModuleMember -Variable *

# SIG # Begin signature block
# MIIXrQYJKoZIhvcNAQcCoIIXnjCCF5oCAQExCzAJBgUrDgMCGgUAMGkGCisGAQQB
# gjcCAQSgWzBZMDQGCisGAQQBgjcCAR4wJgIDAQAABBAfzDtgWUsITrck0sYpfvNR
# AgEAAgEAAgEAAgEAAgEAMCEwCQYFKw4DAhoFAAQUwzz8BUMFydsOnya9cT2FW9O5
# 9AqgghKkMIID7jCCA1egAwIBAgIQfpPr+3zGTlnqS5p31Ab8OzANBgkqhkiG9w0B
# AQUFADCBizELMAkGA1UEBhMCWkExFTATBgNVBAgTDFdlc3Rlcm4gQ2FwZTEUMBIG
# A1UEBxMLRHVyYmFudmlsbGUxDzANBgNVBAoTBlRoYXd0ZTEdMBsGA1UECxMUVGhh
# d3RlIENlcnRpZmljYXRpb24xHzAdBgNVBAMTFlRoYXd0ZSBUaW1lc3RhbXBpbmcg
# Q0EwHhcNMTIxMjIxMDAwMDAwWhcNMjAxMjMwMjM1OTU5WjBeMQswCQYDVQQGEwJV
# UzEdMBsGA1UEChMUU3ltYW50ZWMgQ29ycG9yYXRpb24xMDAuBgNVBAMTJ1N5bWFu
# dGVjIFRpbWUgU3RhbXBpbmcgU2VydmljZXMgQ0EgLSBHMjCCASIwDQYJKoZIhvcN
# AQEBBQADggEPADCCAQoCggEBALGss0lUS5ccEgrYJXmRIlcqb9y4JsRDc2vCvy5Q
# WvsUwnaOQwElQ7Sh4kX06Ld7w3TMIte0lAAC903tv7S3RCRrzV9FO9FEzkMScxeC
# i2m0K8uZHqxyGyZNcR+xMd37UWECU6aq9UksBXhFpS+JzueZ5/6M4lc/PcaS3Er4
# ezPkeQr78HWIQZz/xQNRmarXbJ+TaYdlKYOFwmAUxMjJOxTawIHwHw103pIiq8r3
# +3R8J+b3Sht/p8OeLa6K6qbmqicWfWH3mHERvOJQoUvlXfrlDqcsn6plINPYlujI
# fKVOSET/GeJEB5IL12iEgF1qeGRFzWBGflTBE3zFefHJwXECAwEAAaOB+jCB9zAd
# BgNVHQ4EFgQUX5r1blzMzHSa1N197z/b7EyALt0wMgYIKwYBBQUHAQEEJjAkMCIG
# CCsGAQUFBzABhhZodHRwOi8vb2NzcC50aGF3dGUuY29tMBIGA1UdEwEB/wQIMAYB
# Af8CAQAwPwYDVR0fBDgwNjA0oDKgMIYuaHR0cDovL2NybC50aGF3dGUuY29tL1Ro
# YXd0ZVRpbWVzdGFtcGluZ0NBLmNybDATBgNVHSUEDDAKBggrBgEFBQcDCDAOBgNV
# HQ8BAf8EBAMCAQYwKAYDVR0RBCEwH6QdMBsxGTAXBgNVBAMTEFRpbWVTdGFtcC0y
# MDQ4LTEwDQYJKoZIhvcNAQEFBQADgYEAAwmbj3nvf1kwqu9otfrjCR27T4IGXTdf
# plKfFo3qHJIJRG71betYfDDo+WmNI3MLEm9Hqa45EfgqsZuwGsOO61mWAK3ODE2y
# 0DGmCFwqevzieh1XTKhlGOl5QGIllm7HxzdqgyEIjkHq3dlXPx13SYcqFgZepjhq
# IhKjURmDfrYwggSjMIIDi6ADAgECAhAOz/Q4yP6/NW4E2GqYGxpQMA0GCSqGSIb3
# DQEBBQUAMF4xCzAJBgNVBAYTAlVTMR0wGwYDVQQKExRTeW1hbnRlYyBDb3Jwb3Jh
# dGlvbjEwMC4GA1UEAxMnU3ltYW50ZWMgVGltZSBTdGFtcGluZyBTZXJ2aWNlcyBD
# QSAtIEcyMB4XDTEyMTAxODAwMDAwMFoXDTIwMTIyOTIzNTk1OVowYjELMAkGA1UE
# BhMCVVMxHTAbBgNVBAoTFFN5bWFudGVjIENvcnBvcmF0aW9uMTQwMgYDVQQDEytT
# eW1hbnRlYyBUaW1lIFN0YW1waW5nIFNlcnZpY2VzIFNpZ25lciAtIEc0MIIBIjAN
# BgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAomMLOUS4uyOnREm7Dv+h8GEKU5Ow
# mNutLA9KxW7/hjxTVQ8VzgQ/K/2plpbZvmF5C1vJTIZ25eBDSyKV7sIrQ8Gf2Gi0
# jkBP7oU4uRHFI/JkWPAVMm9OV6GuiKQC1yoezUvh3WPVF4kyW7BemVqonShQDhfu
# ltthO0VRHc8SVguSR/yrrvZmPUescHLnkudfzRC5xINklBm9JYDh6NIipdC6Anqh
# d5NbZcPuF3S8QYYq3AhMjJKMkS2ed0QfaNaodHfbDlsyi1aLM73ZY8hJnTrFxeoz
# C9Lxoxv0i77Zs1eLO94Ep3oisiSuLsdwxb5OgyYI+wu9qU+ZCOEQKHKqzQIDAQAB
# o4IBVzCCAVMwDAYDVR0TAQH/BAIwADAWBgNVHSUBAf8EDDAKBggrBgEFBQcDCDAO
# BgNVHQ8BAf8EBAMCB4AwcwYIKwYBBQUHAQEEZzBlMCoGCCsGAQUFBzABhh5odHRw
# Oi8vdHMtb2NzcC53cy5zeW1hbnRlYy5jb20wNwYIKwYBBQUHMAKGK2h0dHA6Ly90
# cy1haWEud3Muc3ltYW50ZWMuY29tL3Rzcy1jYS1nMi5jZXIwPAYDVR0fBDUwMzAx
# oC+gLYYraHR0cDovL3RzLWNybC53cy5zeW1hbnRlYy5jb20vdHNzLWNhLWcyLmNy
# bDAoBgNVHREEITAfpB0wGzEZMBcGA1UEAxMQVGltZVN0YW1wLTIwNDgtMjAdBgNV
# HQ4EFgQURsZpow5KFB7VTNpSYxc/Xja8DeYwHwYDVR0jBBgwFoAUX5r1blzMzHSa
# 1N197z/b7EyALt0wDQYJKoZIhvcNAQEFBQADggEBAHg7tJEqAEzwj2IwN3ijhCcH
# bxiy3iXcoNSUA6qGTiWfmkADHN3O43nLIWgG2rYytG2/9CwmYzPkSWRtDebDZw73
# BaQ1bHyJFsbpst+y6d0gxnEPzZV03LZc3r03H0N45ni1zSgEIKOq8UvEiCmRDoDR
# EfzdXHZuT14ORUZBbg2w6jiasTraCXEQ/Bx5tIB7rGn0/Zy2DBYr8X9bCT2bW+IW
# yhOBbQAuOA2oKY8s4bL0WqkBrxWcLC9JG9siu8P+eJRRw4axgohd8D20UaF5Mysu
# e7ncIAkTcetqGVvP6KUwVyyJST+5z3/Jvz4iaGNTmr1pdKzFHTx/kuDDvBzYBHUw
# ggTQMIIDuKADAgECAgEHMA0GCSqGSIb3DQEBCwUAMIGDMQswCQYDVQQGEwJVUzEQ
# MA4GA1UECBMHQXJpem9uYTETMBEGA1UEBxMKU2NvdHRzZGFsZTEaMBgGA1UEChMR
# R29EYWRkeS5jb20sIEluYy4xMTAvBgNVBAMTKEdvIERhZGR5IFJvb3QgQ2VydGlm
# aWNhdGUgQXV0aG9yaXR5IC0gRzIwHhcNMTEwNTAzMDcwMDAwWhcNMzEwNTAzMDcw
# MDAwWjCBtDELMAkGA1UEBhMCVVMxEDAOBgNVBAgTB0FyaXpvbmExEzARBgNVBAcT
# ClNjb3R0c2RhbGUxGjAYBgNVBAoTEUdvRGFkZHkuY29tLCBJbmMuMS0wKwYDVQQL
# EyRodHRwOi8vY2VydHMuZ29kYWRkeS5jb20vcmVwb3NpdG9yeS8xMzAxBgNVBAMT
# KkdvIERhZGR5IFNlY3VyZSBDZXJ0aWZpY2F0ZSBBdXRob3JpdHkgLSBHMjCCASIw
# DQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALngyxDUr3a91JNi6zBkuIEIbMME
# 2WIXji//PmXPj85i5jxSHNoWRUtVq3hrY4NikM4PaWyZyBoUi0zMRTPqiNyeo68r
# /oBhnXlXxM8u9D8wPF1H/JoWvMM3lkFRjhFLVPgovtCMvvAwOB7zsCb4Zkdjbd5x
# JkePOEdT0UYdtOPcAOpFrL28cdmqbwDb280wOnlPX0xH+B3vW8LEnWA7sbJDkdik
# M07qs9YnT60liqXG9NXQpq50BWRXiLVEVdQtKjo++Li96TIKApRkxBY6UPFKrud5
# M68MIAd/6N8EOcJpAmxjUvp3wRvIdIfIuZMYUFQ1S2lOvDvTSS4f3MHSUvsCAwEA
# AaOCARowggEWMA8GA1UdEwEB/wQFMAMBAf8wDgYDVR0PAQH/BAQDAgEGMB0GA1Ud
# DgQWBBRAwr0njsw0gzCiM9f7bLPwtCyAzjAfBgNVHSMEGDAWgBQ6moUHEGcotu/2
# vQVBbiDBlNoP3jA0BggrBgEFBQcBAQQoMCYwJAYIKwYBBQUHMAGGGGh0dHA6Ly9v
# Y3NwLmdvZGFkZHkuY29tLzA1BgNVHR8ELjAsMCqgKKAmhiRodHRwOi8vY3JsLmdv
# ZGFkZHkuY29tL2dkcm9vdC1nMi5jcmwwRgYDVR0gBD8wPTA7BgRVHSAAMDMwMQYI
# KwYBBQUHAgEWJWh0dHBzOi8vY2VydHMuZ29kYWRkeS5jb20vcmVwb3NpdG9yeS8w
# DQYJKoZIhvcNAQELBQADggEBAAh+bJMQyDi4lqmQS/+hX08E72w+nIgGyVCPpnP3
# VzEbvrzkL9v4utNb4LTn5nliDgyi12pjczG19ahIpDsILaJdkNe0fCVPEVYwxLZE
# nXssneVe5u8MYaq/5Cob7oSeuIN9wUPORKcTcA2RH/TIE62DYNnYcqhzJB61rCIO
# yheJYlhEG6uJJQEAD83EG2LbUbTTD1Eqm/S8c/x2zjakzdnYLOqum/UqspDRTXUY
# ij+KQZAjfVtL/qQDWJtGssNgYIP4fVBBzsKhkMO77wIv0hVU7kQV2Qqup4oz7bEt
# djYm3ATrn/dhHxXch2/uRpYoraEmfQoJpy4Eo428+LwEMAEwggUzMIIEG6ADAgEC
# AgkAlwn07EG7bckwDQYJKoZIhvcNAQELBQAwgbQxCzAJBgNVBAYTAlVTMRAwDgYD
# VQQIEwdBcml6b25hMRMwEQYDVQQHEwpTY290dHNkYWxlMRowGAYDVQQKExFHb0Rh
# ZGR5LmNvbSwgSW5jLjEtMCsGA1UECxMkaHR0cDovL2NlcnRzLmdvZGFkZHkuY29t
# L3JlcG9zaXRvcnkvMTMwMQYDVQQDEypHbyBEYWRkeSBTZWN1cmUgQ2VydGlmaWNh
# dGUgQXV0aG9yaXR5IC0gRzIwHhcNMTgwNTAyMTgwNjM3WhcNMjAwNjEyMTk0MTIz
# WjB0MQswCQYDVQQGEwJVUzEWMBQGA1UECBMNTWFzc2FjaHVzZXR0czEPMA0GA1UE
# BxMGQm9zdG9uMR0wGwYDVQQKExRQcm94eSBOZXR3b3JrcywgSW5jLjEdMBsGA1UE
# AxMUUHJveHkgTmV0d29ya3MsIEluYy4wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw
# ggEKAoIBAQDBajmeyJxUF2BLSCG5EI2XSjrkE3ac4LHOR4AJtSSnMFLiWQIph2Zf
# x5hIYB776GJFRXVieAPW+t3lmOf5RYIhbNc8xxIJ3/VSXZKBl7iTPDkc1EERwI8d
# Uw3mCw6QYkS2taY3pBhYSqTLloWeaWpETjj3euW5BZcSK3HKeHay6PpN92HhzdLL
# PTyAdH3TSr99QCLdyNzlTiSLaRMfEypZ87r7yK4QIU6sYKTSo7Tm1pUvkXeQIcQs
# tVnkAa3eeGFBjFQLQNpDhlZogwFipOJqWjiuDALO17+JoTgDggg63XRrVsgWdDow
# R2KGzwP6xXufP0McNJyGPOCxF1m9xP2BAgMBAAGjggGFMIIBgTAMBgNVHRMBAf8E
# AjAAMBMGA1UdJQQMMAoGCCsGAQUFBwMDMA4GA1UdDwEB/wQEAwIHgDA1BgNVHR8E
# LjAsMCqgKKAmhiRodHRwOi8vY3JsLmdvZGFkZHkuY29tL2dkaWcyczUtNC5jcmww
# XQYDVR0gBFYwVDBIBgtghkgBhv1tAQcXAjA5MDcGCCsGAQUFBwIBFitodHRwOi8v
# Y2VydGlmaWNhdGVzLmdvZGFkZHkuY29tL3JlcG9zaXRvcnkvMAgGBmeBDAEEATB2
# BggrBgEFBQcBAQRqMGgwJAYIKwYBBQUHMAGGGGh0dHA6Ly9vY3NwLmdvZGFkZHku
# Y29tLzBABggrBgEFBQcwAoY0aHR0cDovL2NlcnRpZmljYXRlcy5nb2RhZGR5LmNv
# bS9yZXBvc2l0b3J5L2dkaWcyLmNydDAfBgNVHSMEGDAWgBRAwr0njsw0gzCiM9f7
# bLPwtCyAzjAdBgNVHQ4EFgQUhXo2BaqNUEfl8vkqaW+RGSI/1JAwDQYJKoZIhvcN
# AQELBQADggEBAINdQ5UlRfjELvPD20WsfmQUTs6IxmAHBX87XaXv+OmhDTG2MJ8a
# cuCF3rsPFX2LNH+jQ8op4qlWdEjwyqdmgUh4b93gDI0RO1eo4b0/cuArcCW9tg7F
# lpwoi0zogmr/PcTzqql/flT64IQUFE9DpoENBnaXJyUJK2op5RixuxFeKRFcn6Vu
# hRlR5yAOydXtOf9vCcDrnLinlGtXGFhAKlOlXHf+vUsNH2tj4BJdOWzrtyf8dPDi
# EQNjil2EkBsIA6z3xvwN/rtqlirMaxZloYZjx61ZTqrnjZ7ZaHpDhw0ImhWoh9du
# HOh2qGF+YugB3jfE/VitbQWC4+GU5ncUqu8xggRzMIIEbwIBATCBwjCBtDELMAkG
# A1UEBhMCVVMxEDAOBgNVBAgTB0FyaXpvbmExEzARBgNVBAcTClNjb3R0c2RhbGUx
# GjAYBgNVBAoTEUdvRGFkZHkuY29tLCBJbmMuMS0wKwYDVQQLEyRodHRwOi8vY2Vy
# dHMuZ29kYWRkeS5jb20vcmVwb3NpdG9yeS8xMzAxBgNVBAMTKkdvIERhZGR5IFNl
# Y3VyZSBDZXJ0aWZpY2F0ZSBBdXRob3JpdHkgLSBHMgIJAJcJ9OxBu23JMAkGBSsO
# AwIaBQCgeDAYBgorBgEEAYI3AgEMMQowCKACgAChAoAAMBkGCSqGSIb3DQEJAzEM
# BgorBgEEAYI3AgEEMBwGCisGAQQBgjcCAQsxDjAMBgorBgEEAYI3AgEVMCMGCSqG
# SIb3DQEJBDEWBBQvoFSTYT0NqdF0n+iGHsyjEOIAWTANBgkqhkiG9w0BAQEFAASC
# AQALZJSAEBfdjecWpxFRp8AfQnX12ELrbod5LOR/hkIYfH8iCFBc1q5JsYH5jsif
# WejPGvIZbXYqJJQcW+DjbYcUkB0F8uahcN6J9G21iBQSwy62wbr889JzsrJ8YyVf
# njW8szhg3OY4c22GAbRQE3CJQJjE8v2kE+9D24nlNmY0NxA9ZDs7xfVNlRpCs/9A
# HQgP1OL0m1QPu5jKFu9oUrrVxn7cIDh3WKJHs9ecgBhMa1CoA6AXS2VN6VQSUths
# Ety3leoIpFwakKWOFiOyAombP4LPEvrV4daOj/F37lsr3bDIqxfx74WNDhkaUf37
# q2Qp3dSPwzNsWC3tjHSZBJgooYICCzCCAgcGCSqGSIb3DQEJBjGCAfgwggH0AgEB
# MHIwXjELMAkGA1UEBhMCVVMxHTAbBgNVBAoTFFN5bWFudGVjIENvcnBvcmF0aW9u
# MTAwLgYDVQQDEydTeW1hbnRlYyBUaW1lIFN0YW1waW5nIFNlcnZpY2VzIENBIC0g
# RzICEA7P9DjI/r81bgTYapgbGlAwCQYFKw4DAhoFAKBdMBgGCSqGSIb3DQEJAzEL
# BgkqhkiG9w0BBwEwHAYJKoZIhvcNAQkFMQ8XDTE4MTIxMjIwMDgxNlowIwYJKoZI
# hvcNAQkEMRYEFIAAMz3S2SWi6jeYoPUMOt3HRVgxMA0GCSqGSIb3DQEBAQUABIIB
# AGAt4hkJiLx39eDoldNn4GWXrdDK13lYBNbxJ5RTiP5QNXjC2gsJNGtpUqI+2Xlw
# aJOklz6yeWl54VfdGZgDou1jXcMZlV/ShVOU0KrbVzK5zCw4ItjmmMAlEHO/EZ51
# 4BEY11GJ7LhpWrOeimvAQutWDFh+b4u1QG9WN/QlJyHRC5Iz/+xcGnIIJGSd0+Xm
# yBbnFUq4jNOMvgLzEG6Ux8NxAK4/SfD1KKTSMa3vpNoyaJMGRgXbBc8JZ24wwwVw
# wj53UeHlGpAHPT+03eUd78xD0kcCnregjkOOq29+aXX76hjmm+iLq0fG2Xfi2TJa
# CIBItJ3jXNC+9hc6Z/shkvc=
# SIG # End signature block
