##############################################################################
##
## Powershell Script for adding Gateway configuration to the Host Settings.
## Script assumes that connection to the target Host is already exists.
##
## Examples:
## 
## PS> .\Add-GatewayToHostConfig.ps1 -gateway 'localhost' -protocol 'tcp'
## 
## PS> Import-Module Proxy-HostAdmin
## PS> Connect-Host -gateway 'specifier' -hostkey 'guid'
## PS> .\Add-GatewayToHostConfig.ps1 -gateway 'localhost' -protocol 'tcp'
## 
##############################################################################

param([string]$gateway = $(throw "Please provide Gateway station specifier")
    , [string]$protocol =$(throw "Please provide Protocol, - IP|TCP|SSL|WS|WSS"))

# Imports
if (-not (Get-Module Proxy-HostAdmin))
{
    Import-Module Proxy-HostAdmin
}

$hostHA = Get-HostConnection
if (-not $hostHA)
{
    Write-Error -message "Must have connection to Host already being established."
    return
}

# Add the specified Gateway to the Host Gateway configuration list, if it's not already there
foreach ($gconfig in $hostHA.settings.getGatewayConfigs())
{
    if ($gconfig.gatewayStationSpecifier -eq $gateway -and $gconfig.gatewayProtocol -eq $protocol)
    {
    	Write-Error "Found a Gateway Configuration with the same Gateway Station Specifier and Protocol."
    	return
    }
}

$gconfigKey = $hostHA.settings.addGatewayConfig($protocol, $gateway, -1, 0, 0)

Write-Host "Added Gateway Config ($gateway via $protocol) to Host Configuration"
