﻿##############################################################################
##
## Power Shell Script to delete Gateway Groups that match a pattern
##
## Examples:
## 
## PS> .\Delete-MatchingGatewayGroups.ps1 -gateway 'localhost'
## 
##############################################################################

param(
	[string]$gateway = $(throw "Please provide Gateway Identifier")
    , [string]$protocol ='TCP'
    , [string]$credentials = '')

# Imports
if (-not (Get-Module Proxy-Gateway))
{
    Import-Module Proxy-Gateway
}

# Make sure we are not connected to Gateway as we can only have one connection per Powershell session.
Disconnect-Gateway

# Connect to Gateway
$null = Connect-Gateway -station $gateway -protocol $protocol -credentials $credentials
$gws = Get-GatewayObject
if (-not $gws)
{
    Write-Error -message "Failed to connect to Gateway Server - exiting"
    return
}

# Get all of the Gateway Groups, find the subset that match the pattern,
# then walk that list and delete each group.
$gws.getAllGroups() | Where-Object {$_.groupname -match "^OU="} | ForEach-Object { Write-Output "Deleting group: $($_.groupname)"; $_.deletegroup(); }

Disconnect-Gateway
