##############################################################################
##
## Powershell Script for removing Gateway's configurations from the 
## Host Settings.
## Script assumes that connection to the target Host is already exists.
##
## Examples:
## 
## PS> .\Remove-GatewayFromHostConfig.ps1 -gateway 'localhost'
## 
## PS> Import-Module Proxy-HostAdmin
## PS> Connect-Host -gateway 'specifier' -hostkey 'w={guid}'
## PS> .\Remove-GatewayFromHostConfig.ps1 -gateway 'localhost'
## 
##############################################################################

param([string]$gateway = $(throw "Please provide Gateway station specifier"))

# Imports
if (-not (Get-Module Proxy-HostAdmin))
{
    Import-Module Proxy-HostAdmin
}

# Remove the specified Gateway from the Host's Gateway Configuration list, if it's there.

$hostHA = Get-HostConnection
if (-not $hostHA)
{
    Write-Error -message "Must have connection to Host already being established."
    return
}

$hostHA.settings.getGatewayConfigs() | Where-Object { $_.gatewayStationSpecifier -eq $gateway } | ForEach-Object { $_.deleteGatewayConfig() }
